==> haskell-gridtables-0.1.1.0-17.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gridtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gridtables
version:              0.1.1.0
visibility:           public
id:                   gridtables-0.1.1.0-EV443V3UxZB3rKLqAiBFRG
key:                  gridtables-0.1.1.0-EV443V3UxZB3rKLqAiBFRG
license:              MIT
copyright:            © 2022-2023 Posit Software, PBC
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/gridtables
synopsis:             Parser for reStructuredText-style grid tables.
description:
    Provides a parser for plain-text representations of
    tables. This package supports table headers, cells
    spanning multiple columns or rows, as well as a way
    to specfiy column alignments.

category:             Text
abi:                  b771e53bbdae50ffe2d7a41771ecc2c5
exposed:              True
exposed-modules:
    Text.GridTable Text.GridTable.ArrayTable Text.GridTable.Parse
    Text.GridTable.Trace

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gridtables
hs-libraries:         HSgridtables-0.1.1.0-EV443V3UxZB3rKLqAiBFRG
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    doclayout-0.5-G2Wm2VuIsgJ2QywWYn7p6r parsec-3.1.16.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-gridtables/html/gridtables.haddock
haddock-html:         /usr/share/doc/haskell-gridtables/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gridtables-0.1.1.0-18-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-gridtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gridtables
version:              0.1.1.0
visibility:           public
id:                   gridtables-0.1.1.0-DPpC9SuuJAA9yyMqrFWi1a
key:                  gridtables-0.1.1.0-DPpC9SuuJAA9yyMqrFWi1a
license:              MIT
copyright:            © 2022-2023 Posit Software, PBC
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/gridtables
synopsis:             Parser for reStructuredText-style grid tables.
description:
    Provides a parser for plain-text representations of
    tables. This package supports table headers, cells
    spanning multiple columns or rows, as well as a way
    to specfiy column alignments.

category:             Text
abi:                  47a7c988f768671a0bee9f5056261f64
exposed:              True
exposed-modules:
    Text.GridTable Text.GridTable.ArrayTable Text.GridTable.Parse
    Text.GridTable.Trace

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gridtables-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gridtables
hs-libraries:         HSgridtables-0.1.1.0-DPpC9SuuJAA9yyMqrFWi1a
depends:
    array-0.5.6.0 base-4.18.2.1 containers-0.6.7
    doclayout-0.5-9EZxKgaNTpvH3oLmqoAtl2 parsec-3.1.16.1 text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-gridtables/html/gridtables.haddock
haddock-html:         /usr/share/doc/haskell-gridtables/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
